import { createApp } from 'vue'

import Cookies from 'js-cookie'
import VueUeditorWrap from 'vue-ueditor-wrap';
import ElementPlus from 'element-plus'
import locale from 'element-plus/es/locale/lang/zh-cn' // 中文语言
// import 'dayjs/locale/zh-cn'

import '@/assets/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'
import directive from './directive' // directive
import lazyPlugin from 'vue3-lazy'



// 注册指令
import plugins from './plugins' // plugins
import { download } from '@/utils/request'
// svg图标
import 'virtual:svg-icons-register'
import SvgIcon from '@/components/SvgIcon'
import elementIcons from '@/components/SvgIcon/svgicon'

// permission control
import './permission'

//// 全局JavaScript时间库
import dayjs from "dayjs";
import isBetween from 'dayjs/plugin/isBetween';
import isSameOrBefore from 'dayjs/plugin/isSameOrBefore';
dayjs.extend(isSameOrBefore)
dayjs.extend(isBetween);

// 全局js公共方法库
import regex from '@/utils/regex'// 全局正则表达式库
import { parseTime, resetForm, addDateRange, handleTree, selectDictLabel, selectDictLabels } from '@/utils/ruoyi'

// 文件上传组件
import FileUpload from "@/components/FileUpload"
// 图片上传组件
import ImageUpload from "@/components/ImageUpload"
// 图片预览组件
import ImagePreview from "@/components/ImagePreview"
// 自定义树选择组件
import TreeSelect from '@/components/TreeSelect'
// 字典标签组件
import DictTag from '@/components/DictTag'






const app = createApp(App)

// 全局方法挂载
app.config.globalProperties.$echart = ref('default')
app.config.globalProperties.download = download
app.config.globalProperties.parseTime = parseTime
app.config.globalProperties.resetForm = resetForm
app.config.globalProperties.handleTree = handleTree
app.config.globalProperties.addDateRange = addDateRange
app.config.globalProperties.selectDictLabel = selectDictLabel
app.config.globalProperties.selectDictLabels = selectDictLabels
app.config.globalProperties.dayjs = dayjs
app.config.globalProperties.regex = regex



// 全局组件挂载
app.component('DictTag', DictTag)
app.component('TreeSelect', TreeSelect)
app.component('FileUpload', FileUpload)
app.component('ImageUpload', ImageUpload)
app.component('ImagePreview', ImagePreview)
app.use(router)
app.use(store)
app.use(plugins)
app.use(elementIcons)
app.use(VueUeditorWrap)
app.use(lazyPlugin, {
    loading: '/loading.gif',
    error: '/error.png',
})
app.component('svg-icon', SvgIcon)

directive(app)

// 使用element-plus 并且设置全局的大小
app.use(ElementPlus, {
    locale: locale,
    // 支持 large、default、small
    size: Cookies.get('size') || 'default'
})
app.config.warnHandler = () => null //全局去除浏览器告警
app.mount('#app')